pub struct SystemInfo {Show 17 fields
pub version: String,
pub uptime_seconds: u64,
pub memory_usage_mb: u64,
pub cpu_usage_percent: f64,
pub active_threads: usize,
pub total_routes: usize,
pub total_fixtures: usize,
pub peak_memory_usage_mb: u64,
pub peak_cpu_usage_percent: f64,
pub peak_error_rate: f64,
pub peaks_since: Option<DateTime<Utc>>,
pub tps: f64,
pub peak_tps: f64,
pub rps_200: f64,
pub peak_rps_200: f64,
pub cps: f64,
pub peak_cps: f64,
}Fields
version: Stringuptime_seconds: u64memory_usage_mb: u64cpu_usage_percent: f64active_threads: usizetotal_routes: usizetotal_fixtures: usizepeak_memory_usage_mb: u64peak_cpu_usage_percent: f64peak_error_rate: f64peaks_since: Option<DateTime<Utc>>tps: f64Successful (200..=399) responses per second, sampled over the last metrics interval. “API transactions/sec” in load-testing terms.
peak_tps: f64rps_200: f64200-OK responses per second over the last metrics interval.
peak_rps_200: f64cps: f64Accepted TCP connections per second (plain HTTP path; reads 0 for HTTPS-only setups).
peak_cps: f64Trait Implementations
Sourceimpl Clone for SystemInfo
impl Clone for SystemInfo
Sourcefn clone(&self) -> SystemInfo
fn clone(&self) -> SystemInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SystemInfo
impl Debug for SystemInfo
Sourceimpl<'de> Deserialize<'de> for SystemInfo
impl<'de> Deserialize<'de> for SystemInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more